Markets
=======

This module contains market-related functionality.

.. automodule:: financepype.markets.candle
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: financepype.markets.funding
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: financepype.markets.market
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: financepype.markets.position
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: financepype.markets.trade
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: financepype.markets.trading_pair
    :members:
    :undoc-members:
    :show-inheritance:
